@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2006-2018 The PHP Group                                |
+  | Copyright (c) 2006-2019 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -91,7 +91,12 @@ struct xdevapi_exception : public std::runtime_error
 		authentication_failure,
 		runtime_error,
 		session_closed,
-		offset_without_limit_not_allowed
+		offset_without_limit_not_allowed,
+		ps_unknown_message,
+		ps_limit_not_supported,
+		session_reset_failure,
+		conn_attrib_wrong_type,
+		conn_attrib_dup_key
 	};
 
 	xdevapi_exception(Code code);
