@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2006-2018 The PHP Group                                |
+  | Copyright (c) 2006-2019 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -184,6 +184,16 @@ decode_pct_path(const util::string& encoded_path)
 }
 /* }}} */
 
+
+/* {{{ operator== */
+bool operator==(const google::protobuf::Message& msg_a,
+				const google::protobuf::Message& msg_b) {
+  return (msg_a.GetTypeName() == msg_b.GetTypeName()) &&
+	  (msg_a.SerializeAsString() == msg_b.SerializeAsString());
+}
+/* }}} */
+
+
 } // namespace drv
 
 } // namespace mysqlx
